summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepassword.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetepassword.h')
-rw-r--r--kopete/libkopete/kopetepassword.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/libkopete/kopetepassword.h b/kopete/libkopete/kopetepassword.h
index bd6826b9..d2ed5aa2 100644
--- a/kopete/libkopete/kopetepassword.h
+++ b/kopete/libkopete/kopetepassword.h
@@ -20,7 +20,7 @@
#include <tqobject.h>
#include "kopete_export.h"
-namespace KWallet { class Wallet; }
+namespace TDEWallet { class Wallet; }
class TQPixmap;
@@ -40,7 +40,7 @@ namespace Kopete
* The Kopete::Password object is responsible for storing and retrieving a
* password for a plugin or account object.
*
* If the KWallet is active, passwords will be stored in it, otherwise, they
* will be stored in the TDEConfig, in a slightly mangled form.
*/
class KOPETE_EXPORT Password : public TQObject
@@ -212,7 +212,7 @@ class KopetePasswordRequestBase : public virtual TQObject
signals:
void requestFinished( const TQString &password );
public slots:
- virtual void walletReceived( KWallet::Wallet *wallet ) = 0;
+ virtual void walletReceived( TDEWallet::Wallet *wallet ) = 0;
virtual void slotOkPressed() = 0;
virtual void slotCancelPressed() = 0;
};
@@ -40,7 +40,7 @@ namespace Kopete
* password for a plugin or account object.
*
- * If the KWallet is active, passwords will be stored in it, otherwise, they
+ * If the TDEWallet is active, passwords will be stored in it, otherwise, they
* will be stored in the TDEConfig, in a slightly mangled form.
*/